#!/usr/bin/env python

""" TCPChan

    A simple TCP multiplexing library 
"""

__version__ = "0.1.0"
__author__ = "Frank Chang"
__author_email__ = "frank@csie.io"
__license__ = "BSD"
